
*****************************************************************
*
* Program Name: C8_5051.ASM ( 705C8 to 145051 interface )
* Revision: 1.00
* Date: October 7, 1993
*
* Written By: Mark Glenewinkel
*             Motorola CSIC Applications
*
* Assembled Under: P&E Microcomputer Systems IASM05
*
*       *********************************
*       *       Revision History        *
*       *********************************
*
*       Rev     1.00    10/07/93        M.R. Glenewinkel
*       Initial Release
*
*****************************************************************
*
* Program Description:
*
*       This software routine provides a way for MCUs with an
*       SPI module on chip to interface to the Motorola MC145051
*       10 bit, 11 channel analog to digital converter.
*
*       This program specifically uses the MC68HC705C8 MCU
*       to test the code. The HC705C8 "talks" to the 5051 with
*       the appropriate serial data transfer from its SPI module.
*
*       For more information, please consult Motorola
*       Application Note ANXXXX.
*
*****************************************************************

***     Equates for 705C8       ***

PORTA   equ     $00             ;port A data reg
DDRA    equ     $04             ;data dir reg A
PORTB   equ     $01             ;port B data reg
DDRB    equ     $05             ;data dir reg B
PORTC   equ     $02             ;port C data reg
DDRC    equ     $06             ;data dir reg C
SPCR    equ     $0A             ;spi ctrl reg
SPSR    equ     $0B             ;spi status reg
SPDR    equ     $0C             ;spi data reg

CS      equ     1               ;bit # for chip select


***     RAM storage variables   ***

        org     $50             ;start of static RAM
RESULT  rmb     2               ;2 bytes needed for 10 bit result
CHANNEL rmb     1               ;a/d channel #


***     Start of program        ***

        org     $1000           ;start of program

START   lda     #$FF
        sta     PORTA           ;port A = $FF
        sta     DDRA            ;port A all outputs
        sta     PORTB           ;port B = $FF
        sta     DDRB            ;port B all outputs
        sta     PORTC           ;port C = $FF
        sta     DDRC            ;port C all outputs

        lda     #$00            ;CHANNEL = AN0
        sta     CHANNEL

*       Initialize SPI module   *

        lda     #$50            ;turn on spi, mstr mode
        sta     SPCR            ;cpha=cpol=0

*       Send out 16 bit frame   *

        bclr    CS,PORTA        ;CS* is low
        lda     CHANNEL         ;load ACCA with CHANNEL

*       Send out address, receive most significant byte
        sta     SPDR            ;store ACCA to spi data reg
WAIT1   brclr   7,SPSR,WAIT1    ;wait until SPIF flag is set
        lda     SPDR            ;load ACCA with MSB of ADC result
        sta     RESULT          ;store this to MSB of RESULT
        sta     PORTB           ;store the 8 MSBs to Port B

*       Start another SPI transmission to receive the
*         2 least significant bits
        lda     CHANNEL         ;load ACCA with CHANNEL
        sta     SPDR            ;store ACCA to spi data reg
WAIT2   brclr   7,SPSR,WAIT2    ;wait until SPIF flag is set
        lda     SPDR            ;load ACCA with LSB of ADC result
        sta     RESULT+1        ;store this to LSB of RESULT
        sta     PORTC           ;store the 2 LSBs to Port C

        bset    CS,PORTA        ;CS* is high, end 16 bit frame

*       Wait for ever until reset
FOR     bra     FOR             ;branch to itself


        org     $1FFE           ;define reset vector
        dw      START


