
*****************************************************************
*
* Program Name: K1_5051.ASM ( 705K1 to 145051 interface )
* Revision: 1.00
* Date: September 22, 1993
*
* Written By: Mark Glenewinkel
*             Motorola CSIC Applications
*
* Assembled Under: P&E Microcomputer Systems IASM05
*
*       *********************************
*       *       Revision History        *
*       *********************************
*
*       Rev     1.00    09/22/93        M.R. Glenewinkel
*       Initial Release
*
*****************************************************************
*
* Program Description:
*
*       This software routine provides a way for MCUs with no
*       SPI module on chip to interface to the Motorola MC145051
*       10 bit, 11 channel analog to digital converter.
*
*       This program specifically uses the MC68HC705K1 MCU to
*       test the code. The HC705K1 "bit bangs" the 5051 with the
*       appropriate serial data transfer the 5051 understands.
*
*       For more information, please consult Motorola
*       Application Note ANXXXX.
*
*****************************************************************

***     Equates for 705K1       ***

PORTA   equ     $00             ;port A data reg
PORTB   equ     $01             ;port B data reg
DDRA    equ     $04             ;data dir reg A
DDRB    equ     $05             ;data dir reg B

CS      equ     0               ;bit # for chip select
SER_CLK equ     1               ;bit # for serial clock
SER_OUT equ     2               ;bit # for serial data out
SER_IN  equ     3               ;bit # for serial data in


***     RAM storage variables   ***

        org     $E0             ;start of static RAM
RESULT  rmb     2               ;2 bytes needed for 10 bit result
CHANNEL rmb     1               ;a/d channel #
TMP_CHN rmb     1               ;temp a/d channel for routine


***     Start of program        ***

        org     $200            ;start of user eprom

***     Initialization          *
START   lda     #$01            ;init port A
        sta     PORTA
        lda     #$07            ;init i/o of port A
        sta     DDRA

***     Init CS to low to start a/d
        bclr    CS,PORTA        ;CS* line is low

        lda     CHANNEL         ;load ACCA with a/d channel #
                                ;(for emulation, init $E2=$00)
        sta     TMP_CHN         ;store ACCA to temp channel
        clr     RESULT+1        ;clear result regs
        clr     RESULT
        ldx     #4T             ;init counter for LOOP1

***     Read the serial input pin
LOOP1   brclr   SER_IN,PORTA,L1_1   ;carry bit = serial in
L1_1    rol     RESULT+1        ;rotate left result
        rol     RESULT

***     Write the serial output pin
        rol     TMP_CHN         ;rotate left TMP_CHN
        brclr   4,TMP_CHN,L1_2  ;if tmp_chn bit4 = 0, goto L1_2
        bset    SER_OUT,PORTA   ;ser_out = 1
        bra     L1_3            ;goto L1_3
L1_2    bclr    SER_OUT,PORTA   ;ser_out = 0

***     Clock the serial clock pin
L1_3    bset    SER_CLK,PORTA   ;ser_clk = 1
        bclr    SER_CLK,PORTA   ;ser_clk = 0

        decx                    ;decrease counter loop
        bne     LOOP1           ;is LOOP1 finished?


        ldx     #6T             ;init counter for LOOP2

***     Read the serial input pin
LOOP2   brclr   SER_IN,PORTA,L2 ;carry bit = serial in
L2      rol     RESULT+1        ;rotate left result
        rol     RESULT

***     Clock the serial clock pin
        bset    SER_CLK,PORTA   ;ser_clk = 1
        bclr    SER_CLK,PORTA   ;ser_clk = 0

        decx                    ;decrease counter loop
        bne     LOOP2           ;is LOOP2 finished?

***     CS* high to finish serial transfer
        bset    CS,PORTA        ;CS* line is high

FOR     BRA     FOR             ;branch forever

        org     $03FE           ;reset vector
        dw      START


